@@ -1,5 +1,6 @@
 """Exception classes."""
-import urllib3
+
+from ._gen.rest import RESTResponse
 
 
 class MyHomeException(Exception):
@@ -9,7 +10,7 @@ class MyHomeException(Exception):
 class LoginFailure(MyHomeException):
     """Login failure."""
 
-    def __init__(self, resp: urllib3.response.HTTPResponse, message: str):
+    def __init__(self, resp: RESTResponse, message: str):
         """Construct exception."""
         self.resp = resp
         super().__init__(message)
@@ -18,7 +19,7 @@ class LoginFailure(MyHomeException):
 class RemoteAccessDenied(LoginFailure):
     """Remote access is not permitted for given user."""
 
-    def __init__(self, resp: urllib3.response.Response):
+    def __init__(self, resp: RESTResponse):
         """Construct exception."""
         super().__init__(resp, "Remote access denied for user")
 
@@ -26,7 +27,7 @@ class RemoteAccessDenied(LoginFailure):
 class UnknownLoginFailure(LoginFailure):
     """Unknown login failure."""
 
-    def __init__(self, resp: urllib3.response.Response):
+    def __init__(self, resp: RESTResponse):
         """Construct exception."""
         super().__init__(resp, "An unknown issue has occurred during login")
 
@@ -34,6 +35,6 @@ class UnknownLoginFailure(LoginFailure):
 class LoginDenied(LoginFailure):
     """Username and/or password incorrect."""
 
-    def __init__(self, resp: urllib3.response.Response):
+    def __init__(self, resp: RESTResponse):
         """Construct exception."""
         super().__init__(resp, "Username and/or password incorrect")
